@@ -19,6 +19,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
+#include "config.h"
 
 #include <stdio.h>
 #include <errno.h>
@@ -28,38 +29,37 @@
 #include <pwd.h>
 
 #include "vlock.h"
-#include "nls.h"
-#include "kbd_error.h"
+
+#include "libcommon.h"
 
 /*
  * Try to find out proper login name.
  */
 const char *
-get_username (void)
+get_username(void)
 {
 	const char *name;
-	struct passwd *pw = 0;
-	uid_t   uid = getuid ();
+	struct passwd *pw = NULL;
+	uid_t uid         = getuid();
 
-	char   *logname = getenv ("LOGNAME");
+	char *logname = getenv("LOGNAME");
 
-	if (logname)
-	{
-		pw = getpwnam (logname);
+	if (logname) {
+		pw = getpwnam(logname);
 		/* Ensure uid is same as current. */
 		if (pw && pw->pw_uid != uid)
-			pw = 0;
+			pw = NULL;
 	}
 	if (!pw)
-		pw = getpwuid (uid);
+		pw = getpwuid(uid);
 
 	if (!pw)
-		kbd_error (EXIT_FAILURE, 0, _("unrecognized user"));
+		kbd_error(EXIT_FAILURE, 0, _("unrecognized user"));
 
-	name = strdup (pw->pw_name);
+	name = strdup(pw->pw_name);
 	if (!name)
-		kbd_error (EXIT_FAILURE, errno, "strdup");
+		kbd_error(EXIT_FAILURE, errno, "strdup");
 
-	endpwent ();
+	endpwent();
 	return name;
 }
