@@ -9,6 +9,10 @@ topdir="${testdir%/*}"
 set -x
 cd "$topdir"
 
+uname -a
+free -h
+ulimit -a
+
 chmod 666 "$TTY"
 kbd_mode -f -u -C "$TTY"
 
