@@ -6,10 +6,8 @@
 
 #include "libcommon.h"
 
-int main(int __attribute__((unused)) argc, char **argv)
+int main(int argc KBD_ATTR_UNUSED, char **argv)
 {
-	set_progname(argv[0]);
-
 	struct lk_ctx *ctx;
 	struct kbdfile *fp;
 	struct kbdfile_ctx *kbdfile_ctx;
