@@ -13,8 +13,8 @@ main(int argc KBD_ATTR_UNUSED, char **argv KBD_ATTR_UNUSED)
 	if (!fp)
 		kbd_error(EXIT_FAILURE, 0, "unable to create kbdfile");
 
-	const char *const dirpath[]  = { "", TESTDIR "/data/findfile/test_0/keymaps/**", 0 };
-	const char *const suffixes[] = { ".kmap", ".map", "", 0 };
+	const char *const dirpath[]  = { "", TESTDIR "/data/findfile/test_0/keymaps/**", NULL };
+	const char *const suffixes[] = { ".kmap", ".map", "", NULL };
 
 	const char *expect = TESTDIR "/data/findfile/test_0/keymaps/i386/qwertz/test2.kmap";
 
